@@ -80,16 +80,25 @@ class AbstractLayout:
         _app = tri.get_app_instance()
         _app.layout = self.html
 
-    def start(self, port=None, debug=False):
+    def start(self, port=None, debug=None):
         """
         Start the application server.
 
         :param port: Which port to run the server on
-        :param debug: Whether to enable debugging tools. Defaults to False.
-        :type debug: bool
+        :param debug: Whether to enable debugging tools. Defaults to
+                      None, in which case it is set to True if the --dev
+                      flag was passed as a command line argument.
+        :type debug: bool or None
         """
         _app = tri.get_app_instance()
 
+        if debug is None:
+            parser = _app.cli_parser
+            args, _unknown = parser.parse_known_args()
+            debug = args.dev
+
+        _app._debug = debug
+
         _app.name = self.name
         _app.layout = self.html
         _app.on_ready = tri.print_server_info()
@@ -119,7 +128,7 @@ class AbstractLayout:
                 tri.compose_callbacks(self.on_ready, on_server_listening)
             )
         else:
-            _app.on_ready = compose_callbacks(self.on_ready, on_server_listening)
+            _app.on_ready = tri.compose_callbacks(self.on_ready, on_server_listening)
 
         # Dev validation
         tri.validate_key_names()
@@ -159,7 +168,7 @@ class AbstractLayout:
             )
             client_process.start()
 
-        _app.on_ready = compose_callbacks(self.on_ready, start_client)
+        _app.on_ready = tri.compose_callbacks(self.on_ready, start_client)
 
         # Dev validation
         tri.validate_key_names()
